@@ -15,7 +15,7 @@
 
 #include <Akonadi/AgentInstance>
 #include <Akonadi/AgentManager>
-#include <contactsearchjob.h>
+#include <Akonadi/ContactSearchJob>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/FreeBusy>
@@ -29,7 +29,7 @@
 #include <KLocalizedString>
 #include <QUrl>
 
-#include <KJobWidgets/KJobWidgets>
+#include <KJobWidgets>
 #include <QDir>
 #include <QFile>
 #include <QRegularExpression>
@@ -932,12 +932,12 @@ KCalendarCore::FreeBusy::Ptr FreeBusyManager::loadFreeBusy(const QString &email)
     QFile f(fbd + QLatin1Char('/') + email + QStringLiteral(".ifb"));
     if (!f.exists()) {
         qCDebug(AKONADICALENDAR_LOG) << f.fileName() << "doesn't exist.";
-        return KCalendarCore::FreeBusy::Ptr();
+        return {};
     }
 
     if (!f.open(QIODevice::ReadOnly)) {
         qCDebug(AKONADICALENDAR_LOG) << "Unable to open file" << f.fileName();
-        return KCalendarCore::FreeBusy::Ptr();
+        return {};
     }
 
     QTextStream ts(&f);
